﻿using Newtonsoft.Json;
using ProjectOpticsStore.Entities;
using ProjectOpticsStore.Entities.Enums;
using System.ComponentModel;
using System.Linq;

public class Order
{
    public int Id { get; private set; }

    [Browsable(false)]
    public int CustomerId { get; private set; }

    [DisplayName("Заказчик")]
    public string CustomerName { get; private set; } = string.Empty;

    [DisplayName("Товары")]

    // Объединение строк
    public string Product => OrderProducts != null ?
        string.Join(", ", OrderProducts.Select(x => $"{x.Type} {x.Quantity}")) :
        string.Empty;

    [DisplayName("Cтатус")]
    public OrderStatusEnum Status { get; private set; } = OrderStatusEnum.Pending;

    [DisplayName("Дата заказа")]
    public DateTime DateCreated { get; private set; }

    [Browsable(false)]
    // Коллекция, описывающая связь "Order_Product"
    [JsonIgnore] public IEnumerable<Order_Product> OrderProducts { get; private set; } = new List<Order_Product>();

    public static Order CreateOperation(int id, int customerId, IEnumerable<Order_Product> orderProducts, OrderStatusEnum status = OrderStatusEnum.Pending)
    {
        return new Order
        {
            Id = id,
            CustomerId = customerId,
            DateCreated = DateTime.Now,
            Status = status,
            OrderProducts = orderProducts
        };
    }
    public void SetOrderProducts(IEnumerable<Order_Product> products)
    {
        if (products != null && products.Any())
        {
            OrderProducts = products;
        }
    }
}
