﻿using ProjectOpticsStore.Entities;
using ProjectOpticsStore.Repositories;

namespace ProjectOpticsStore.Forms;

public partial class FormCustomer : Form
{
    private readonly ICustomerRepository _customerRepository;
    private int? _customerId;

    // Конструктор принимает экземпляр ICustomerRepository
    public FormCustomer(ICustomerRepository customerRepository)
    {
        InitializeComponent();
        _customerRepository = customerRepository ?? throw new ArgumentNullException(nameof(customerRepository));
    }

    public int Id
    {
        set
        {
            try
            {
                var customer = _customerRepository.ReadCustomerById(value);
                if (customer == null)
                {
                    throw new InvalidDataException(nameof(customer));
                }

                textBoxFullName.Text = customer.FullName;
                _customerId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxFullName.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_customerId.HasValue)
            {
                // Если редактируем существующего клиента
                _customerRepository.UpdateCustomer(CreateCustomer(_customerId.Value));
            }
            else
            {
                // Если создаем нового клиента
                _customerRepository.CreateCustomer(CreateCustomer(0));
            }

            Close(); // Закрываем форму после сохранения
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    // Метод для создания объекта Customer
    private Customer CreateCustomer(int id) => Customer.CreateEntity(id, textBoxFullName.Text);
}