﻿using ProjectOpticsStore.Repositories;
namespace ProjectOpticsStore.Forms;

public partial class FormOrders : Form
{
    private readonly IOrderRepository _orderRepository;
    private readonly ICustomerRepository _customerRepository;
    private readonly IProductRepository _productRepository;

    public FormOrders(IOrderRepository orderRepository, ICustomerRepository customerRepository, IProductRepository productRepository)
    {
        InitializeComponent();
        _orderRepository = orderRepository ?? throw new ArgumentNullException(nameof(orderRepository));
        _customerRepository = customerRepository ?? throw new ArgumentNullException(nameof(customerRepository));
        _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository));
    }
    // Загрузка списка заказов при загрузке формы
    private void FormOrders_Load(object sender, EventArgs e)
    {
        try
        {
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    // Кнопка для добавления нового заказа
    private void ButtonAdd_Click(object sender, EventArgs e)
    {
        try
        {
            // Передаем все три зависимости в конструктор FormOrder
            using (var form = new FormOrder(_orderRepository, _customerRepository, _productRepository))
            {
                form.ShowDialog();
            }
            LoadList(); // Перезагружаем список после добавления
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }


    // Метод для загрузки списка заказов в DataGridView
    private void LoadList()
    {

        dataGridViewOrders.DataSource = _orderRepository.ReadOrders();
        dataGridViewOrders.Columns["Id"].Visible = false;
        dataGridViewOrders.Columns["DateCreated"].DefaultCellStyle.Format = "dd MMMM yyyy hh:mm";
    }

    // Метод для получения идентификатора заказа из выбранной строки в DataGridView
    private bool TryGetIdentifierFromSelectedRow(out int id)
    {
        id = 0;
        if (dataGridViewOrders.SelectedRows.Count < 1)
        {
            MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            return false;
        }

        id = Convert.ToInt32(dataGridViewOrders.SelectedRows[0].Cells["Id"].Value);
        return true;
    }
}
