﻿using ProjectOpticsStore.Reports;
using ProjectOpticsStore.Repositories;
using ProjectOpticsStore.Repositories.Implementations;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Unity;

namespace ProjectOpticsStore.Forms
{
    public partial class FormProductReport : Form
    {
        IUnityContainer _container;
        public FormProductReport(IUnityContainer container, IProductRepository productRepository)
        {
            InitializeComponent();
            _container = container ?? throw new ArgumentNullException(nameof(container));
            comboBoxProducts.DataSource = productRepository.ReadProducts();
            comboBoxProducts.DisplayMember = "Type";
            comboBoxProducts.ValueMember = "Id";
        }

        private void ButtonSelectFilePath_Click(object sender, EventArgs e)
        {
            var sfd = new SaveFileDialog()
            {
                Filter = "Excel Files | *.xlsx"
            };
            if (sfd.ShowDialog() != DialogResult.OK)
            {
                return;
            }
            textBoxFilePath.Text = sfd.FileName;
        }
        private void ButtonMakeReport_Click(object sender, EventArgs e)
        {


            try
            {
                if (string.IsNullOrWhiteSpace(textBoxFilePath.Text))
                {
                    throw new Exception("Отсутствует имя файла для отчета");
                }
                if (comboBoxProducts.SelectedIndex < 0)
                {
                    throw new Exception("Не выбран корм");
                }
                if (dateTimePickerEndDate.Value <= dateTimePickerStartDate.Value)
                {
                    throw new Exception("Дата начала должна быть раньше даты окончания");
                }
                if (_container.Resolve<TableReport>().CreateTable(textBoxFilePath.Text, (int)comboBoxProducts.SelectedValue!,
                    dateTimePickerStartDate.Value, dateTimePickerEndDate.Value))
                {
                    MessageBox.Show("Документ сформирован", "Формирование документа", MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
                else
                {
                    MessageBox.Show("Возникли ошибки при формировании документа.Подробности в логах", "Формирование документа",
                        MessageBoxButtons.OK, MessageBoxIcon.Information);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при создании очета", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
