﻿using DocumentFormat.OpenXml.Office2010.PowerPoint;
using ProjectOpticsStore.Entities;
using ProjectOpticsStore.Repositories;

namespace ProjectOpticsStore.Forms;

public partial class FormStore : Form
{
    private readonly IStoreRepository _storeRepository;
    private int? _storeId;

    public int Id
    {
        set
        {
            try
            {
                // Загрузка данных магазина
                var store = _storeRepository.ReadStoreById(value);
                if (store == null)
                {
                    throw new InvalidDataException(nameof(store));
                }

                textBoxAddress.Text = store.Address;
                textBoxOrganisation.Text = store.Organisation;
                _storeId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public FormStore(IStoreRepository storeRepository)
    {
        InitializeComponent();
        _storeRepository = storeRepository ?? throw new ArgumentNullException(nameof(storeRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            // Проверка на заполненность обязательных полей
            if (string.IsNullOrWhiteSpace(textBoxAddress.Text))
            {
                throw new Exception("Адрес магазина не указан.");
            }

            if (string.IsNullOrWhiteSpace(textBoxOrganisation.Text))
            {
                throw new Exception("Организация магазина не указана.");
            }

            // Сохранение данных
            if (_storeId.HasValue)
            {
                _storeRepository.UpdateStore(CreateStore(_storeId.Value));
            }
            else
            {
                _storeRepository.CreateStore(CreateStore(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e)
    {
        Close();
    }

    private Store CreateStore(int id)
    {
        // Создание сущности Store
        return Store.CreateEntity(id, textBoxAddress.Text, textBoxOrganisation.Text);
    }
}
