﻿using ProjectOpticsStore.Entities;
using ProjectOpticsStore.Repositories;
using Unity;

namespace ProjectOpticsStore.Forms;

public partial class FormStores : Form
{
    private readonly IUnityContainer _container;
    private readonly IStoreRepository _storeRepository;

    public FormStores(IUnityContainer container, IStoreRepository storeRepository)
    {
        InitializeComponent();
        _container = container ?? throw new ArgumentNullException(nameof(container));
        _storeRepository = storeRepository ?? throw new ArgumentNullException(nameof(storeRepository));
    }

    private void FormStores_Load(object sender, EventArgs e)
    {
        try
        {
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonAdd_Click(object sender, EventArgs e)
    {
        try
        {
            _container.Resolve<FormStore>().ShowDialog();
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonUpd_Click(object sender, EventArgs e)
    {
        if (!TryGetIdentifierFromSelectedRow(out var storeId))
        {
            return;
        }

        try
        {
            var form = _container.Resolve<FormStore>();
            form.Id = storeId;
            form.ShowDialog();
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при изменении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonDel_Click(object sender, EventArgs e)
    {
        if (!TryGetIdentifierFromSelectedRow(out var storeId))
        {
            return;
        }

        if (MessageBox.Show("Удалить запись?", "Удаление", MessageBoxButtons.YesNo) != DialogResult.Yes)
        {
            return;
        }

        try
        {
            _storeRepository.DeleteStore(storeId);
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void LoadList()
    {
        // Загрузка списка магазинов в DataGridView
        dataGridViewStores.DataSource = _storeRepository.ReadStores().ToList();
        dataGridViewStores.Columns["Id"].Visible = false;
        dataGridViewStores.Columns["FullInformation"].Visible = false;
    }

    private bool TryGetIdentifierFromSelectedRow(out int id)
    {
        id = 0;
        if (dataGridViewStores.SelectedRows.Count < 1)
        {
            MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            return false;
        }

        // Получение идентификатора выбранного магазина
        id = Convert.ToInt32(dataGridViewStores.SelectedRows[0].Cells["Id"].Value);
        return true;
    }
}
