﻿
using Unity;

namespace ProjectOpticsStore.Forms;

public partial class FormSupplies : Form
{
    private readonly IUnityContainer _container;
    private readonly ISupplyRepository _supplyRepository;

    public FormSupplies(IUnityContainer container, ISupplyRepository supplyRepository)
    {
        InitializeComponent();
        _container = container ?? throw new ArgumentNullException(nameof(container));
        _supplyRepository = supplyRepository ?? throw new ArgumentNullException(nameof(supplyRepository));
    }

    private void FormSupplies_Load(object sender, EventArgs e)
    {
        try
        {
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonAdd_Click(object sender, EventArgs e)
    {
        try
        {
            _container.Resolve<FormSupply>().ShowDialog();
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void LoadList()
    {
        // Загрузка списка поставок в DataGridView
        dataGridViewSupplies.DataSource = _supplyRepository.ReadSupplies().ToList();
        dataGridViewSupplies.Columns["Id"].Visible = false;
        dataGridViewSupplies.Columns["OperationDate"].DefaultCellStyle.Format = "dd.MM.yyyy";
    }

    private void ButtonDel_Click(object sender, EventArgs e)
    {
        if (!TryGetIdentifierFromSelectedRow(out var orderId))
        {
            return;
        }

        if (MessageBox.Show("Удалить запись?", "Удаление", MessageBoxButtons.YesNo) != DialogResult.Yes)
        {
            return;
        }

        try
        {
            _supplyRepository.DeleteSupply(orderId);
            LoadList();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private bool TryGetIdentifierFromSelectedRow(out int id)
    {
        id = 0;
        if (dataGridViewSupplies.SelectedRows.Count < 1)
        {
            MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            return false;
        }

        // Получение идентификатора выбранного магазина
        id = Convert.ToInt32(dataGridViewSupplies.SelectedRows[0].Cells["Id"].Value);
        return true;
    }
}
