﻿using ProjectOpticsStore.Entities;
using ProjectOpticsStore.Repositories;

namespace ProjectOpticsStore.Forms;

public partial class FormSupply : Form
{
    private readonly ISupplyRepository _supplyRepository;
    private readonly IStoreRepository _storeRepository;
    private readonly IProductRepository _productRepository;

    public FormSupply(ISupplyRepository supplyRepository, IStoreRepository storeRepository, IProductRepository productRepository)
    {
        InitializeComponent();
        _supplyRepository = supplyRepository ?? throw new ArgumentNullException(nameof(supplyRepository));
        _storeRepository = storeRepository ?? throw new ArgumentNullException(nameof(storeRepository));
        _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository));

        // Инициализация ComboBox для магазинов
        comboBoxStore.DataSource = _storeRepository.ReadStores().ToList();
        comboBoxStore.DisplayMember = "FullInformation";
        comboBoxStore.ValueMember = "Id";

        // Инициализация ComboBox для товаров
        comboBoxProduct.DataSource = _productRepository.ReadProducts().ToList();
        comboBoxProduct.DisplayMember = "Type";
        comboBoxProduct.ValueMember = "Id";

        // Устанавливаем дату как текущую и блокируем редактирование
        dateTimePickerOperationDate.Value = DateTime.Now;
        dateTimePickerOperationDate.Enabled = false;
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            // Проверка на заполненность полей
            if (comboBoxStore.SelectedIndex < 0 || comboBoxProduct.SelectedIndex < 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            // Создание новой поставки
            var supply = Supply.CreateOperation(
                id: 0, // Новый объект, идентификатор пока 0
                storeId: (int)comboBoxStore.SelectedValue!,
                productId: (int)comboBoxProduct.SelectedValue!,
                quantity: (int)numericUpDownQuantity.Value
            );

            _supplyRepository.CreateSupply(supply);

            MessageBox.Show("Поставка успешно добавлена", "Успех", MessageBoxButtons.OK, MessageBoxIcon.Information);
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e)
    {
        Close();
    }
}
