﻿using Microsoft.Extensions.Logging;
using ProjectOpticsStore.Repositories;
namespace ProjectOpticsStore.Reports;

public class DocReport
{
    private readonly ICustomerRepository _customerRepository;
    private readonly IStoreRepository _storeRepository;
    private readonly IProductRepository _productRepository;
    private readonly ILogger<DocReport> _logger;

    public DocReport(ICustomerRepository customerRepository, IStoreRepository storeRepository,
        IProductRepository productRepository, ILogger<DocReport> logger)
    {
        _customerRepository = customerRepository ?? throw new ArgumentNullException(nameof(customerRepository));
        _storeRepository = storeRepository ?? throw new ArgumentNullException(nameof(storeRepository));
        _productRepository = productRepository ?? throw new ArgumentNullException(nameof(productRepository));
        _logger = logger ?? throw new ArgumentNullException(nameof(logger)); ;
    }

    public bool CreateDoc(string filePath, bool includeCustomers, bool includeStores, bool includeProducts)
    {
        try
        {
            var builder = new WordBuilder(filePath).AddHeader("Документ со справочниками");
            if (includeCustomers)
            {
                builder.AddParagraph("Заказчики").AddTable([2400], GetCustomers());
            }
            if (includeStores)
            {
                builder.AddParagraph("Магазины").AddTable([2400, 2400], GetStores());
            }
            if (includeProducts)
            {
                builder.AddParagraph("Товары").AddTable([2400, 2400, 2400, 2400, 2400, 2400], GetProducts());
            }
            builder.Build();
            return true;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при формировании документа");
            return false;
        }
    }

    private List<string[]> GetCustomers()
    {
        return [
            ["ФИО Заказчика"],
            .. _customerRepository
            .ReadCustomers()
            .Select(x => new string[] { x.FullName}),
        ];
    }

    private List<string[]> GetStores()
    {
        return [
            ["Адрес магазина", "Организация"],
            .. _storeRepository
            .ReadStores()
            .Select(x => new string[] { x.Address, x.Organisation}),
        ];
    }

    private List<string[]> GetProducts()
    {
        return [
            ["Тип", "Мощность", "Цена", "Магазин","Толщина", "Болезнь"],
            .. _productRepository
            .ReadProducts()
            .Select(x => new string[] {x.Type.ToString(), x.Power.ToString(), x.Price.ToString(), x.Store.ToString(), x.Thickness.ToString(), x.Disease}),
        ];
    }
}